@@ -10,13 +10,15 @@ relaxinfo <- function() {
   if (!interactive()) {
     cat(
       "The optmatch package makes essential use of D. P. Bertsekas\n",
-      "and P. Tseng\'s RELAX-IV algorithm and code, as well as\n" ,
-      "Bertsekas\' AUCTION algorithm and code:\n\n",
+      "and P. Tseng\'s RELAX-IV algorithm and code:\n\n",
       "Bersekas, D. P. and  Tseng, P., \"Relaxation Methods for\n",
       "Minimum Cost ...\" Operations Research, vol. 26, 1988, 93-114;\n",
       "Bertsekas, D. P., \"An Auction/Sequential Shortest Path\n" ,
       "Algorithm for the Minimum Cost Flow Problem\", LIDS Report\n" ,
       "P-2146, MIT, Nov. 1992;\n",
+      "Bertsekas, D.P., Linear Network Optimization, MIT Press, 1991;\n",
+      "Bertsekas, D.P., Network Optimization: Continuous and Discrete\n",
+      "Models, Athena Scientific, 1998;\n",
       "<http://web.mit.edu/dimitrib/www/noc.htm>.\n\n",
       "Bertsekas and Tseng freely permit their software to be used for\n",
       "research purposes, but non-research uses, including the use of it\n",
@@ -35,13 +37,14 @@ relaxinfo <- function() {
     outConn <- file(outFile, open="w")
     writeLines(paste(
       "The optmatch package makes essential use of D. P. Bertsekas\nand ",
-      "P. Tseng\'s RELAX-IV algorithm and code, as well as\nBertsekas\' " ,
-      "AUCTION algorithm and code:\n\nBersekas, ",
+      "P. Tseng\'s RELAX-IV algorithm and code:\n\nBersekas, ",
       "D. P. and  Tseng, P., \"Relaxation Methods for\nMinimum ",
       "Cost ...\" Operations Research, vol. 26, 1988, 93-114;\nBertsekas, ",
       "D. P., \"An Auction/Sequential Shortest Path\nAlgorithm " ,
       "for the Minimum Cost Flow Problem\", LIDS Report\nP-2146, " ,
-      "MIT, Nov. 1992;\n<http:",
+      "MIT, Nov. 1992;\nBertsekas, D.P., Linear Network Optimization, ",
+      "MIT Press, 1991;\nBertsekas, D.P., Network Optimization: Continuous ",
+      "and Discrete\nModels, Athena Scientific, 1998;\n<http:",
       "//web.mit.edu/dimitrib/www/noc.htm>.\n\nBertsekas ",
       "and Tseng freely permit their software to be used for\nresearch ",
       "purposes, but non-research uses, including the use of it\nto ",
